@@ -7,7 +7,7 @@
 #
 # Usage   : obo_trimming.pl my_ontology.obo term_ids.txt> my_ontology_trimmed.obo
 #
-# License : Copyright (C) 2006-2011 by Erick Antezana. All rights reserved.
+# License : Copyright (c) 2006-2012 by Erick Antezana. All rights reserved.
 #           This program is free software; you can redistribute it and/or
 #           modify it under the same terms as Perl itself.
 #
@@ -37,7 +37,7 @@ foreach my $term_id (@term_ids) {
 }
 
 # export the new trimmed ontology
-$ontology->export('obo');
+$ontology->export('obo', \*STDOUT);
 
 exit 0;
 
@@ -62,7 +62,7 @@ Erick Antezana, E<lt>erick.antezana -@- gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006-2011 by Erick Antezana
+Copyright (c) 2006-2012 by Erick Antezana
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.7 or,
